Workflows
=========

.. autoclass:: chancy.plugins.workflow.WorkflowPlugin
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: chancy.plugins.workflow.Workflow
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: chancy.plugins.workflow.WorkflowStep
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: chancy.plugins.workflow.Sequence
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: chancy.plugins.workflow.api
   :members:
   :undoc-members:
   :show-inheritance:
